<?php

namespace Dzariq\Dzariq\Policies;

use Litepie\User\Contracts\UserPolicy;
use Dzariq\Dzariq\Models\SurveyAnswer;

class SurveyAnswerPolicy
{

    /**
     * Determine if the given user can view the survey_answer.
     *
     * @param UserPolicy $user
     * @param SurveyAnswer $survey_answer
     *
     * @return bool
     */
    public function view(UserPolicy $user, SurveyAnswer $survey_answer)
    {
        if ($user->canDo('dzariq.survey_answer.view') && $user->isAdmin()) {
            return true;
        }

        return $survey_answer->user_id == user_id() && $survey_answer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a survey_answer.
     *
     * @param UserPolicy $user
     * @param SurveyAnswer $survey_answer
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('dzariq.survey_answer.create');
    }

    /**
     * Determine if the given user can update the given survey_answer.
     *
     * @param UserPolicy $user
     * @param SurveyAnswer $survey_answer
     *
     * @return bool
     */
    public function update(UserPolicy $user, SurveyAnswer $survey_answer)
    {
        if ($user->canDo('dzariq.survey_answer.edit') && $user->isAdmin()) {
            return true;
        }

        return $survey_answer->user_id == user_id() && $survey_answer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given survey_answer.
     *
     * @param UserPolicy $user
     * @param SurveyAnswer $survey_answer
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, SurveyAnswer $survey_answer)
    {
        return $survey_answer->user_id == user_id() && $survey_answer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given survey_answer.
     *
     * @param UserPolicy $user
     * @param SurveyAnswer $survey_answer
     *
     * @return bool
     */
    public function verify(UserPolicy $user, SurveyAnswer $survey_answer)
    {
        if ($user->canDo('dzariq.survey_answer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given survey_answer.
     *
     * @param UserPolicy $user
     * @param SurveyAnswer $survey_answer
     *
     * @return bool
     */
    public function approve(UserPolicy $user, SurveyAnswer $survey_answer)
    {
        if ($user->canDo('dzariq.survey_answer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
