<?php

namespace Dzariq\Dzariq\Policies;

use Litepie\User\Contracts\UserPolicy;
use Dzariq\Dzariq\Models\Survey;

class SurveyPolicy
{

    /**
     * Determine if the given user can view the survey.
     *
     * @param UserPolicy $user
     * @param Survey $survey
     *
     * @return bool
     */
    public function view(UserPolicy $user, Survey $survey)
    {
        if ($user->canDo('dzariq.survey.view') && $user->isAdmin()) {
            return true;
        }

        return $survey->user_id == user_id() && $survey->user_type == user_type();
    }

    /**
     * Determine if the given user can create a survey.
     *
     * @param UserPolicy $user
     * @param Survey $survey
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('dzariq.survey.create');
    }

    /**
     * Determine if the given user can update the given survey.
     *
     * @param UserPolicy $user
     * @param Survey $survey
     *
     * @return bool
     */
    public function update(UserPolicy $user, Survey $survey)
    {
        if ($user->canDo('dzariq.survey.edit') && $user->isAdmin()) {
            return true;
        }

        return $survey->user_id == user_id() && $survey->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given survey.
     *
     * @param UserPolicy $user
     * @param Survey $survey
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Survey $survey)
    {
        return $survey->user_id == user_id() && $survey->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given survey.
     *
     * @param UserPolicy $user
     * @param Survey $survey
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Survey $survey)
    {
        if ($user->canDo('dzariq.survey.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given survey.
     *
     * @param UserPolicy $user
     * @param Survey $survey
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Survey $survey)
    {
        if ($user->canDo('dzariq.survey.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
