<?php

namespace Dzariq\Dzariq\Providers;

use Illuminate\Support\ServiceProvider;

class DzariqServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'dzariq');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'dzariq');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('dzariq.dzariq', function ($app) {
            return $this->app->make('Dzariq\Dzariq\Dzariq');
        });

        // Bind Survey to repository
        $this->app->bind(
            'Dzariq\Dzariq\Interfaces\SurveyRepositoryInterface',
            \Dzariq\Dzariq\Repositories\Eloquent\SurveyRepository::class
        );
        // Bind SurveyAnswer to repository
        $this->app->bind(
            'Dzariq\Dzariq\Interfaces\SurveyAnswerRepositoryInterface',
            \Dzariq\Dzariq\Repositories\Eloquent\SurveyAnswerRepository::class
        );

        $this->app->register(\Dzariq\Dzariq\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Dzariq\Dzariq\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['dzariq.dzariq'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('dzariq/dzariq.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/dzariq')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/dzariq')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
